<?php

// Reminder: always indent with 4 spaces (no tabs).
// +---------------------------------------------------------------------------+
// | GoogleAnalytics Plugin 1.0.0 for Geeklog - The Ultimate Weblog            |
// +---------------------------------------------------------------------------|
// | plugins/googleanalytics/functions.inc                                     |
// +---------------------------------------------------------------------------|
// | Copyright (C) 2009 by hiroron - hiroron AT hiroron DOT com                |
// |                                                                           |
// | Constructed with the Universal Plugin                                     |
// | Copyright (C) 2002 by the following authors:                              |
// | Tom Willett               -    twillett AT users DOT sourceforge DOT net  |
// | Blaine Lang               -    langmail AT sympatico DOT ca               |
// | The Universal Plugin is based on prior work by:                           |
// | Tony Bibbs                -    tony AT tonybibbs DOT com                  |
// | Modified by:                                                              |
// | mystral-kk                -    geeklog AT mystral-kk DOT net              |
// | dengen                    -    taharaxp AT gmail DOT com                  |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+

if (strpos(strtolower($_SERVER['PHP_SELF']), 'functions.inc') !== false) {
    die('This file can not be used on its own.');
}

/**
* Include language file
*/
$plugin_path = $_CONF['path'] . 'plugins/googleanalytics/';
$langfile = $plugin_path . 'language/' . $_CONF['language'] . '.php';

if (file_exists($langfile)) {
    require_once $langfile;
} else {
    require_once $plugin_path . 'language/japanese_utf-8.php';
}

/*
* Check and see if we need to load the plugin configuration
*/
if (!isset($_GANA_CONF['googleanalyticsloginrequired'])) {
    require_once $_CONF['path_system'] . 'classes/config.class.php';

    $plg_config = config::get_instance();
    $_GANA_CONF = $plg_config->get_config('googleanalytics');
}
$_GANA_CONF['version'] = '1.0.0';

// +---------------------------------------------------------------------------+
// | Geeklog Plugin API Implementation                                         |
// +---------------------------------------------------------------------------+

/**
* Called by the plugin Editor to display the current plugin code version
* This may be different than the version installed and registered currently.
* If newer then you may want to run the update
*
* @return   string  version number
*
*/
function plugin_chkVersion_googleanalytics()
{
    global $_GANA_CONF;

    return $_GANA_CONF['version'];
}

/**
* Upgrade the googleanalytics plugin
*
* @return   int     Number of message to display (true = generic success msg)
*
*/
function plugin_upgrade_googleanalytics()
{
    global $_CONF, $_TABLES, $_GANA_CONF;

    // the plugin needs these function so complain when they don't exist
    if (!function_exists('PLG_uninstall') ||
            !function_exists('COM_createLink')) {
        return 3002;
    }

    //// upgrades are done by the install script - return a generic error
    //COM_errorLog("Plugin upgrade function not implemented");
    //return 3001;

    // no db changes - just update the version numbers
    DB_query ("UPDATE {$_TABLES['plugins']} "
            . "SET pi_version = '{$_GANA_CONF['version']}', pi_gl_version = '" . VERSION . "' "
            . "WHERE pi_name = 'googleanalytics'");

    return true;
}

/**
* Automatic uninstall function for plugins
*
* @return   array
*
* This code is automatically uninstalling the plugin.
* It passes an array to the core code function that removes
* tables, groups, features and php blocks from the tables.
* Additionally, this code can perform special actions that cannot be
* foreseen by the core code (interactions with other plugins for example)
*
*/
function plugin_autouninstall_googleanalytics()
{
    $out = array(
        // give the name of the tables, without $_TABLES[]
        'tables' => array('googleanalytics'),

        // give the full name of the group, as in the db
        'groups' => array('GoogleAnalytics Admin'),

        // give the full name of the feature, as in the db
        'features' => array('googleanalytics.admin'),

        //// give the full name of the block, including 'phpblock_', etc
        //'php_blocks' => array('phpblock_googleanalytics'),

        // give all vars with their name
        'vars'=> array()
    );
    return $out;
}

function plugin_templatesetvars_googleanalytics ($templatename, &$template)
{
    global $_GANA_CONF, $_CONF, $_USER;
    
    switch ($templatename) {
        case 'header':
        case 'footer':
            if (isset($_GANA_CONF['gatrackingid']) && $_GANA_CONF['gatrackingid'] != 'UA-XXXXXXX-X') {
                $ua_id = $_GANA_CONF['gatrackingid'];
                if ($_CONF['theme'] == 'mobile_3g' || $_CONF['theme'] == 'mobile') {
                    // mobile
                    if (!empty($_GANA_CONF['gatrackingid_mobile']) && $_GANA_CONF['gatrackingid_mobile'] != 'UA-XXXXXXX-X' ) {
                        $ua_id = $_GANA_CONF['gatrackingid_mobile'];
                    }
                    $ret  = '<!-- mobile GAnalytics .' . $ua_id;
                    $ret .= ' sending(' . googleanalytics_mobile_code_sending($ua_id) . ')';
                    $ret .= ' -->';

                } else {
                    // pc
                    $ret = <<<EOF
<script type="text/javascript">
var gaJsHost = (("https:" == document.location.protocol) ? "https://ssl." : "http://www.");
document.write(unescape("%3Cscript src='" + gaJsHost + "google-analytics.com/ga.js' type='text/javascript'%3E%3C/script%3E"));
</script>
<script type="text/javascript">
try {
var pageTracker = _gat._getTracker("{$ua_id}");
pageTracker._trackPageview();
} catch(err) {}</script>
EOF;

                }
                $template->set_var('googleanalytics', $ret);
            }
    }
}

function googleanalytics_mobile_code_sending ($id)
{
    global $_CONF;

    require_once 'HTTP/Request.php';

    $var_utmac   = $id;
    $var_utmhn   = str_replace('https://', '', $_CONF['site_url']);
    $var_utmhn   = str_replace('http://', '', $var_utmhn);    
    $var_utmn    = rand(1000000000,9999999999);
    $var_cookie  = '';
    $var_today   = time();
    $var_referer = $_SERVER['HTTP_REFERER'];
    $var_uservar = '';
    $var_utmp    = $_SERVER['REQUEST_URI'];
    
    $g_url = 'http://www.google-analytics.com/__utm.gif?utmwv=1&utmn='.$var_utmn.'&utmsr=-&utmsc=-&utmul=-&utmje=0&utmfl=-&utmdt=-&utmhn='.$var_utmhn.'&utmr='.$var_referer.'&utmp='.$var_utmp.'&utmac='.$var_utmac.'&utmcc=__utma%3D'.$var_cookie.'.'.$var_random.'.'.$var_today.'.'.$var_today.'.'.$var_today.'.2%3B%2B__utmb%3D'.$var_cookie.'%3B%2B__utmc%3D'.$var_cookie.'%3B%2B__utmz%3D'.$var_cookie.'.'.$var_today.'.2.2.utmccn%3D(direct)%7Cutmcsr%3D(direct)%7Cutmcmd%3D(none)%3B%2B__utmv%3D'.$var_cookie.'.'.$var_uservar.'%3B';
    
    $header = array();
    //Set the language to that of the client so analytics can track it.
    if (!empty($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
        $header['Accept-language'] = $_SERVER['HTTP_ACCEPT_LANGUAGE'].'\r\n';
    }
    //Set the user agent to that of the client so analytics can track it.
    if (!empty($_SERVER['HTTP_USER_AGENT'])) {
        $header['User-Agent'] = $_SERVER['HTTP_USER_AGENT'].'\r\n';
    }
    
    $req = new HTTP_Request($g_url);
    //$req->setMethod(HTTP_REQUEST_METHOD_HEAD);
    if (count($header) > 0) {
        foreach ( $header as $key => $val ) {
            $req->addHeader($key, $val);
        }
    }
    $response = $req->sendRequest ();
    if (PEAR::isError ($response)) {
        $msg = $response->getMessage();
        COM_errorLog('GANA: mobile code sending error! - ' . $msg);
        return 999;
    } else {
        // all status coce http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html
        return $req->getResponseCode();
    }
}

?>